@@ -25,10 +25,14 @@ BookmarksDialog::BookmarksDialog(Book *book_, QWidget *parent):
         QString label("At ");
         label += QString::number((int)(100 * book_->
             getProgress(bookmark.part, bookmark.pos))) + "%";
+        if (!bookmark.note.isEmpty()) {
+            label += ": " + bookmark.note;
+        }
+        label += "\n";
         int chapterIndex = book_->chapterFromPart(bookmark.part);
         if (chapterIndex != -1) {
             QString chapterId = book_->chapters[chapterIndex];
-            label += "\nIn \"" + book_->content[chapterId].name + "\"";
+            label += "In \"" + book_->content[chapterId].name + "\"";
         }
         data.append(label);
     }
@@ -69,8 +73,14 @@ void BookmarksDialog::onItemActivated(const QModelIndex &index)
 
 void BookmarksDialog::onAdd()
 {
-    emit addBookmark();
-    close();
+    bool ok;
+    QString text = QInputDialog::getText(this, tr("Add bookmark"),
+                                         tr("Note:"), QLineEdit::Normal,
+                                         QString(), &ok);
+    if (ok) {
+        emit addBookmark(text);
+        close();
+    }
 }
 
 void BookmarksDialog::onDelete(bool really)
