@@ -1,8 +1,5 @@
-#include <QtGui>
-#include <QDebug>
-#include <QFileInfo>
 #include <QDir>
-#include <QModelIndex>
+#include <QtGui>
 
 #ifdef Q_WS_MAEMO_5
 #include <QtMaemo5/QMaemo5InformationBox>
@@ -131,7 +128,6 @@ void LibraryDialog::onRemove()
 
 void LibraryDialog::onRead()
 {
-    qDebug() << "LibraryDialog::onRead";
     QModelIndex current = sortedLibrary->mapToSource(list->currentIndex());
     if (current.isValid()) {
         Library::instance()->setNowReading(current);
@@ -147,7 +143,7 @@ void LibraryDialog::onDetails()
 
 void LibraryDialog::onItemActivated(const QModelIndex &index)
 {
-    qDebug() << "LibraryDialog::onItemActivated";
+    TRACE;
     QModelIndex libraryIndex = sortedLibrary->mapToSource(index);
     Book *book = Library::instance()->book(libraryIndex);
     (new InfoDialog(book, this))->exec();
@@ -192,7 +188,7 @@ QModelIndex LibraryDialog::selected() const
 
 void LibraryDialog::onAddFolder()
 {
-    Trace t("LibraryDialog::onAddFolder");
+    TRACE;
 
     // Get folder name
     Settings *settings = Settings::instance();
@@ -235,7 +231,7 @@ void LibraryDialog::onAddFromFolderDone(int added)
 #ifdef Q_WS_MAEMO_5
     QMaemo5InformationBox::information(this, msg);
 #else
-    // FIXME
+    QMessageBox::information(this, tr("Done adding books"), msg);
 #endif
 }
 
@@ -252,10 +248,7 @@ void LibraryDialog::onSearch()
         return;
     }
     progress->setLabelText(tr("Searching Project Gutenberg"));
-    progress->setMinimum(0);
-    progress->setMaximum(0);
-    progress->setValue(0);
-    progress->show();
+    progress->showWait();
     Search::instance()->start(searchDialog->query());
 }
 
@@ -264,12 +257,12 @@ void LibraryDialog::showSearchResults()
     progress->reset();
     QList<Search::Result> results = Search::instance()->results();
     if (results.count() == 0) {
-        QMessageBox::information(this, tr("Search results"), tr("No books found"));
+        QMessageBox::information(this, tr("Search results"),
+                                 tr("No books found"));
         return;
     }
 
     SearchResultsDialog *dialog = new SearchResultsDialog(results, this);
-    // FIXME
     connect(dialog, SIGNAL(add(const Search::Result &)),
             this, SLOT(onAddSearchResult(const Search::Result &)));
     dialog->show();
