@@ -1,12 +1,4 @@
-#include <QDir>
-#include <QString>
-#include <QDebug>
-#include <QtXml>
 #include <qtextdocument.h>  // Qt::escape is currently defined here...
-#include <QDirIterator>
-#include <QFileInfo>
-#include <QtAlgorithms>
-#include <QVariantHash>
 
 #include "book.h"
 #include "opshandler.h"
@@ -47,7 +39,7 @@ QString Book::path() const
 
 bool Book::open()
 {
-    Trace t("Book::open");
+    TRACE;
     qDebug() << path();
     close();
     clear();
@@ -68,7 +60,7 @@ bool Book::open()
 
 void Book::peek()
 {
-    Trace t("Book::peek");
+    TRACE;
     qDebug() << path();
     close();
     clear();
@@ -88,7 +80,7 @@ void Book::peek()
 
 void Book::close()
 {
-    Trace t("Book::close");
+    TRACE;
     content.clear();
     parts.clear();
     QDir::setCurrent(QDir::rootPath());
@@ -104,7 +96,7 @@ QString Book::tmpDir() const
 
 bool Book::extract(const QStringList &excludedExtensions)
 {
-    Trace t("Book::extract");
+    TRACE;
     bool ret = false;
     QString tmp = tmpDir();
     qDebug() << "Extracting" << mPath << "to" << tmp;
@@ -150,7 +142,7 @@ bool Book::extract(const QStringList &excludedExtensions)
 
 bool Book::parse()
 {
-    Trace t("Book::parse");
+    TRACE;
 
     // Parse OPS file
     bool ret = false;
@@ -276,7 +268,7 @@ void Book::clear()
 
 void Book::load()
 {
-    Trace t("Book::load");
+    TRACE;
     qDebug() << "path" << path();
 
     QVariantHash data = BookDb::instance()->load(path());
@@ -307,7 +299,7 @@ void Book::load()
 
 void Book::save()
 {
-    Trace t("Book::save");
+    TRACE;
 
     QVariantHash data;
     data["title"] = title;
@@ -332,7 +324,7 @@ void Book::save()
 
 void Book::setLastBookmark(int part, qreal position)
 {
-    Trace t("Book:setLastBookmark");
+    TRACE;
     qDebug() << "part" << part << "position" << position;
     mLastBookmark.part = part;
     mLastBookmark.pos = position;
@@ -364,7 +356,7 @@ QList<Book::Bookmark> Book::bookmarks() const
 
 QString Book::opsPath()
 {
-    Trace t("Book::opsPath");
+    TRACE;
     QString ret;
 
     QFile container(tmpDir() + "/META-INF/container.xml");
@@ -487,7 +479,7 @@ bool Book::extractMetaData()
 
 void Book::upgrade()
 {
-    Trace t("Book::upgrade");
+    TRACE;
 
     qDebug() << path();
 
@@ -529,6 +521,6 @@ void Book::upgrade()
 
 void Book::remove()
 {
-    Trace t("Book::remove");
+    TRACE;
     BookDb::instance()->remove(path());
 }
